@@ -123,6 +123,9 @@ var annotated_dup =
     [ "pw_registry_methods", "structpw__registry__methods.html", "structpw__registry__methods" ],
     [ "pw_resource", "structpw__resource.html", null ],
     [ "pw_resource_events", "structpw__resource__events.html", "structpw__resource__events" ],
+    [ "pw_security_context", "structpw__security__context.html", null ],
+    [ "pw_security_context_events", "structpw__security__context__events.html", "structpw__security__context__events" ],
+    [ "pw_security_context_methods", "structpw__security__context__methods.html", "structpw__security__context__methods" ],
     [ "pw_session", "structpw__session.html", null ],
     [ "pw_session_events", "structpw__session__events.html", "structpw__session__events" ],
     [ "pw_session_info", "structpw__session__info.html", "structpw__session__info" ],
@@ -134,10 +137,6 @@ var annotated_dup =
     [ "pw_thread_loop_events", "structpw__thread__loop__events.html", "structpw__thread__loop__events" ],
     [ "pw_time", "structpw__time.html", "structpw__time" ],
     [ "pw_work_queue", "structpw__work__queue.html", null ],
-    [ "pwtest_context", "structpwtest__context.html", null ],
-    [ "pwtest_spa_plugin", "structpwtest__spa__plugin.html", "structpwtest__spa__plugin" ],
-    [ "pwtest_suite", "structpwtest__suite.html", null ],
-    [ "pwtest_test", "structpwtest__test.html", null ],
     [ "spa_audio_aec", "structspa__audio__aec.html", "structspa__audio__aec" ],
     [ "spa_audio_aec_events", "structspa__audio__aec__events.html", "structspa__audio__aec__events" ],
     [ "spa_audio_aec_info", "structspa__audio__aec__info.html", "structspa__audio__aec__info" ],
@@ -172,6 +171,7 @@ var annotated_dup =
     [ "spa_dbus_connection_events", "structspa__dbus__connection__events.html", "structspa__dbus__connection__events" ],
     [ "spa_dbus_methods", "structspa__dbus__methods.html", "structspa__dbus__methods" ],
     [ "spa_debug_context", "structspa__debug__context.html", "structspa__debug__context" ],
+    [ "spa_debug_file_ctx", "structspa__debug__file__ctx.html", "structspa__debug__file__ctx" ],
     [ "spa_debug_log_ctx", "structspa__debug__log__ctx.html", "structspa__debug__log__ctx" ],
     [ "spa_device", "structspa__device.html", "structspa__device" ],
     [ "spa_device_events", "structspa__device__events.html", "structspa__device__events" ],
@@ -181,6 +181,7 @@ var annotated_dup =
     [ "spa_dict", "structspa__dict.html", "structspa__dict" ],
     [ "spa_dict_item", "structspa__dict__item.html", "structspa__dict__item" ],
     [ "spa_dll", "structspa__dll.html", "structspa__dll" ],
+    [ "spa_error_location", "structspa__error__location.html", "structspa__error__location" ],
     [ "spa_event", "structspa__event.html", "structspa__event" ],
     [ "spa_event_body", "structspa__event__body.html", "structspa__event__body" ],
     [ "spa_fraction", "structspa__fraction.html", "structspa__fraction" ],
@@ -198,6 +199,7 @@ var annotated_dup =
     [ "spa_i18n_methods", "structspa__i18n__methods.html", "structspa__i18n__methods" ],
     [ "spa_interface", "structspa__interface.html", "structspa__interface" ],
     [ "spa_interface_info", "structspa__interface__info.html", "structspa__interface__info" ],
+    [ "spa_io_async_buffers", "structspa__io__async__buffers.html", "structspa__io__async__buffers" ],
     [ "spa_io_buffers", "structspa__io__buffers.html", "structspa__io__buffers" ],
     [ "spa_io_clock", "structspa__io__clock.html", "structspa__io__clock" ],
     [ "spa_io_latency", "structspa__io__latency.html", "structspa__io__latency" ],
@@ -216,6 +218,7 @@ var annotated_dup =
     [ "spa_log", "structspa__log.html", "structspa__log" ],
     [ "spa_log_methods", "structspa__log__methods.html", "structspa__log__methods" ],
     [ "spa_log_topic", "structspa__log__topic.html", "structspa__log__topic" ],
+    [ "spa_log_topic_enum", "structspa__log__topic__enum.html", "structspa__log__topic__enum" ],
     [ "spa_loop", "structspa__loop.html", "structspa__loop" ],
     [ "spa_loop_control", "structspa__loop__control.html", "structspa__loop__control" ],
     [ "spa_loop_control_hooks", "structspa__loop__control__hooks.html", "structspa__loop__control__hooks" ],
@@ -230,6 +233,7 @@ var annotated_dup =
     [ "spa_meta_cursor", "structspa__meta__cursor.html", "structspa__meta__cursor" ],
     [ "spa_meta_header", "structspa__meta__header.html", "structspa__meta__header" ],
     [ "spa_meta_region", "structspa__meta__region.html", "structspa__meta__region" ],
+    [ "spa_meta_sync_timeline", "structspa__meta__sync__timeline.html", "structspa__meta__sync__timeline" ],
     [ "spa_meta_videotransform", "structspa__meta__videotransform.html", "structspa__meta__videotransform" ],
     [ "spa_node", "structspa__node.html", "structspa__node" ],
     [ "spa_node_callbacks", "structspa__node__callbacks.html", "structspa__node__callbacks" ],
