@@ -26,5 +26,6 @@ var group__pw__loop =
     [ "pw_loop_add_signal", "group__pw__loop.html#ga714ada0b1d2d9092d4e659731ccc4cb8", null ],
     [ "pw_loop_destroy_source", "group__pw__loop.html#ga5ca87923bfa2820ee6e73fbf890bac54", null ],
     [ "pw_loop_new", "group__pw__loop.html#gab6d8a6f58c050fac07ba828c6d5380d3", null ],
-    [ "pw_loop_destroy", "group__pw__loop.html#gade78a07ed3f7a7cb6280485224d65709", null ]
+    [ "pw_loop_destroy", "group__pw__loop.html#gade78a07ed3f7a7cb6280485224d65709", null ],
+    [ "pw_loop_set_name", "group__pw__loop.html#ga8de226f45904d4b9f472ffa9f44db7a1", null ]
 ];
\ No newline at end of file
