@@ -1,5 +1,10 @@
 var NAVTREEINDEX18 =
 {
+"structpw__impl__factory__events.html":[8,4,3,1],
+"structpw__impl__factory__events.html#a61bf0bc918867a1315f7c09e870cf297":[8,4,3,1,0],
+"structpw__impl__factory__events.html#a6bb4670f4a96e31d0f1f30d3fc763bc6":[8,4,3,1,3],
+"structpw__impl__factory__events.html#abb0d82e4263cbe36b38aa10eef130ad0":[8,4,3,1,1],
+"structpw__impl__factory__events.html#ae608dbd84c609b5b8a6d7c232e5a569f":[8,4,3,1,2],
 "structpw__impl__factory__implementation.html":[8,4,3,2],
 "structpw__impl__factory__implementation.html#a99eef2345bd7b402f47ad72beb6ebfe7":[8,4,3,2,1],
 "structpw__impl__factory__implementation.html#ab63e939995687efd690f736730021e7f":[8,4,3,2,0],
@@ -244,10 +249,5 @@ var NAVTREEINDEX18 =
 "structpw__protocol__native__message.html#a32d56d90a40415a584d28262cb30941e":[8,6,3,1,0],
 "structpw__protocol__native__message.html#a45a77f421d3b6b1123b85883e28b48b3":[8,6,3,1,6],
 "structpw__protocol__native__message.html#a60ea6289ac35a79b83b7e1caa0c8edf6":[8,6,3,1,2],
-"structpw__protocol__native__message.html#a6c4a9b3a354cf7f37c8c4aa25de81d67":[8,6,3,1,4],
-"structpw__protocol__native__message.html#abaad1bc5e0c163fa89fea9c0d0852c4f":[8,6,3,1,5],
-"structpw__protocol__native__message.html#ad9a08cd2b12fa38a8d222308270faf40":[8,6,3,1,3],
-"structpw__protocol__native__message.html#aef6ddaa16aeaa35b4276e3b2767268aa":[8,6,3,1,1],
-"structpw__protocol__server.html":[8,4,13,2],
-"structpw__protocol__server.html#a01d6fae5e363f6694f092256c19366ea":[8,4,13,2,3]
+"structpw__protocol__native__message.html#a6c4a9b3a354cf7f37c8c4aa25de81d67":[8,6,3,1,4]
 };
