@@ -1,5 +1,15 @@
 var NAVTREEINDEX19 =
 {
+"structpw__protocol__native__message.html#abaad1bc5e0c163fa89fea9c0d0852c4f":[8,6,3,1,5],
+"structpw__protocol__native__message.html#ad9a08cd2b12fa38a8d222308270faf40":[8,6,3,1,3],
+"structpw__protocol__native__message.html#aef6ddaa16aeaa35b4276e3b2767268aa":[8,6,3,1,1],
+"structpw__protocol__server.html":[8,4,13,2],
+"structpw__protocol__server.html#a01d6fae5e363f6694f092256c19366ea":[8,4,13,2,3],
+"structpw__protocol__server.html#a0ac79f449a098fd48ac49f48f56a0ed3":[8,4,13,2,0],
+"structpw__protocol__server.html#a0b93bd3cd5a2680d8ece4796826406fc":[8,4,13,2,1],
+"structpw__protocol__server.html#acc7b1e9530a048b084976fc647ab446f":[8,4,13,2,4],
+"structpw__protocol__server.html#ae953d4026c613d91a0cb34398d3f4367":[8,4,13,2,2],
+"structpw__proxy.html":[8,3,13,2],
 "structpw__proxy__events.html":[8,3,13,1],
 "structpw__proxy__events.html#a1d91d77027018205abcdfe5f25b0feb1":[8,3,13,1,4],
 "structpw__proxy__events.html#a220d199c1f0a241f1e623686863e8158":[8,3,13,1,6],
@@ -239,15 +249,5 @@ var NAVTREEINDEX19 =
 "structspa__dbus__connection.html#a684f175f4839121d8c976c50ca273303":[8,7,9,1,3,1],
 "structspa__dbus__connection.html#a8b89c910cd288a5e1d2af8216568a3a6":[8,7,9,1,3,0],
 "structspa__dbus__connection__events.html":[8,7,9,1,2],
-"structspa__dbus__connection__events.html#a1e35b4f490157dd9c4194b4a03490fc6":[8,7,9,1,2,1],
-"structspa__dbus__connection__events.html#a2ae8b95b36226127853160f1779260e0":[8,7,9,1,2,0],
-"structspa__dbus__connection__events.html#a481b39049a46ec7d8519c8d2c9318968":[8,7,9,1,2,2],
-"structspa__dbus__methods.html":[8,7,9,1,4],
-"structspa__dbus__methods.html#a1e518bcb13046ec6b46a927024b6cc28":[8,7,9,1,4,1],
-"structspa__dbus__methods.html#a6e090fa6083fa425460f631ea48c3434":[8,7,9,1,4,0],
-"structspa__debug__context.html":[8,7,3,10],
-"structspa__debug__context.html#af9f0b4808459f1701213a4dbac14601f":[8,7,3,10,0],
-"structspa__debug__file__ctx.html":[8,7,3,11],
-"structspa__debug__file__ctx.html#a34708c6380f0ca51b9d318a089306401":[8,7,3,11,1],
-"structspa__debug__file__ctx.html#a817d19045e3261030ec8e38842a018c3":[8,7,3,11,0]
+"structspa__dbus__connection__events.html#a1e35b4f490157dd9c4194b4a03490fc6":[8,7,9,1,2,1]
 };
