@@ -1,5 +1,10 @@
 var NAVTREEINDEX21 =
 {
+"structspa__log__topic.html#ab77cbaf7b01d2f4dddbcf7f51766b9d6":[8,7,9,3,3,1],
+"structspa__log__topic__enum.html":[8,7,9,3,4],
+"structspa__log__topic__enum.html#a3306c265f098ac2ccf248c9977c1cc9e":[8,7,9,3,4,2],
+"structspa__log__topic__enum.html#ab100eb5174eac7bbb5fb2766f569bab4":[8,7,9,3,4,1],
+"structspa__log__topic__enum.html#acc701c2634125be347e22fd995a4e08c":[8,7,9,3,4,0],
 "structspa__loop.html":[8,7,9,4,1],
 "structspa__loop.html#a6cd472082b361bc90f66c41b0dccea96":[8,7,9,4,1,0],
 "structspa__loop__control.html":[8,7,9,4,2],
@@ -244,10 +249,5 @@ var NAVTREEINDEX21 =
 "structspa__port__info.html#a0d1d7545d48016fa95629bf71b26c949":[8,7,6,21,2],
 "structspa__port__info.html#a3f9832799f2903cdd623d71f958fbc5c":[8,7,6,21,3],
 "structspa__port__info.html#a81b330b23307447d948209a19d7a8aee":[8,7,6,21,0],
-"structspa__port__info.html#ab6581ff27cf6d9cc624283ba6beed837":[8,7,6,21,4],
-"structspa__process__latency__info.html":[8,7,7,68],
-"structspa__process__latency__info.html#a1e891c0385d3fb6840019255e4a7bc7f":[8,7,7,68,0],
-"structspa__process__latency__info.html#a93fac86cdd1aca91cc5e57a5ea0340fb":[8,7,7,68,1],
-"structspa__process__latency__info.html#a97e2de30ab39d818003af3e303049801":[8,7,7,68,2],
-"structspa__ratelimit.html":[9,0,280]
+"structspa__port__info.html#ab6581ff27cf6d9cc624283ba6beed837":[8,7,6,21,4]
 };
