@@ -1,5 +1,8 @@
 var NAVTREEINDEX5 =
 {
+"group__pw__session__manager.html#ga7942053dc37f4422c4342845b98013ca":[8,6,4,115],
+"group__pw__session__manager.html#ga7bd339deb3e56304f3e0e84496d768ad":[8,6,4,107],
+"group__pw__session__manager.html#ga7d86a53322280ecfcc47734de89449fe":[8,6,4,84],
 "group__pw__session__manager.html#ga7dcaf114cea354db4a8f610ed968e2a7":[8,6,4,173],
 "group__pw__session__manager.html#ga7dfd0401a9b75ae042034c7c26dd3c2d":[8,6,4,180],
 "group__pw__session__manager.html#ga7e51bfdb707f25b2222dfae9c6dc7dea":[8,6,4,74],
@@ -117,8 +120,9 @@ var NAVTREEINDEX5 =
 "group__pw__stream.html#gaa727d7a41acb9d0ec574f93f01328d30":[8,0,21],
 "group__pw__stream.html#gaace102fde535955faffb8386a2cd3d9c":[8,0,23],
 "group__pw__stream.html#gaafa1055c167dd99ba94bb49ec30603ba":[8,0,33],
-"group__pw__stream.html#gab93fa91d8ea80e562bb5e8f6b5bafe21":[8,0,36],
+"group__pw__stream.html#gab93fa91d8ea80e562bb5e8f6b5bafe21":[8,0,37],
 "group__pw__stream.html#gabe1c593f34080ea9c8c6231abe4e7386":[8,0,32],
+"group__pw__stream.html#gac987fb3ab601efd721dbd912e21b9136":[8,0,36],
 "group__pw__stream.html#gaca974f99f4545ce623a94c2f06a48dd0":[8,0,15],
 "group__pw__stream.html#gacdd761aac33011a41d1f05cfe9effb11":[8,0,11],
 "group__pw__stream.html#gad9606e2efb479a55ee798f61b82aa49b":[8,0,17],
@@ -245,9 +249,5 @@ var NAVTREEINDEX5 =
 "group__spa__ansi.html#gabcf2363d262cee0526346177c9246c92":[8,7,8,0,24],
 "group__spa__ansi.html#gac75fc46d7948111d087d9dd444cbcb6e":[8,7,8,0,7],
 "group__spa__ansi.html#gacc92b4eb940bdf521a96b02f0261fb6d":[8,7,8,0,32],
-"group__spa__ansi.html#gace360eddb3a5fca36e9a3730606f6fad":[8,7,8,0,10],
-"group__spa__ansi.html#gad05b2989634f1bdd58adce5724527574":[8,7,8,0,29],
-"group__spa__ansi.html#gad9ac3e26ccd0b443d1dcfcbbb6222b3e":[8,7,8,0,2],
-"group__spa__ansi.html#gae27024e6cb0c01d10bca2b1aaed33d60":[8,7,8,0,22],
-"group__spa__ansi.html#gaeb6b06daa60ace33973cba3c2a1e448f":[8,7,8,0,39]
+"group__spa__ansi.html#gace360eddb3a5fca36e9a3730606f6fad":[8,7,8,0,10]
 };
